@@ -5,14 +5,15 @@
 import os
 import asyncio
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Union, Callable, Optional, Awaitable
+from typing import TYPE_CHECKING, Type, Union, Generic, Callable, Optional, Awaitable
 
-from alicebot.typing import T_Event
+from alicebot.config import ConfigModel
 from alicebot.log import error_or_exception
-from alicebot.utils import sync_func_wrapper
+from alicebot.typing import T_Event, T_Config
+from alicebot.utils import is_config_class, sync_func_wrapper
 
 if TYPE_CHECKING:
-    from alicebot import Bot
+    from alicebot.bot import Bot
 
 __all__ = ["Adapter"]
 
@@ -21,7 +22,7 @@ if os.getenv("ALICEBOT_DEV") == "1":
     __import__("pkg_resources").declare_namespace(__name__)
 
 
-class Adapter(ABC):
+class Adapter(Generic[T_Event, T_Config], ABC):
     """协议适配器基类。
 
     Attributes:
@@ -31,6 +32,7 @@ class Adapter(ABC):
 
     name: str
     bot: "Bot"
+    Config: Type[ConfigModel]
 
     def __init__(self, bot: "Bot"):
         if not hasattr(self, "name"):
@@ -38,6 +40,14 @@ class Adapter(ABC):
         self.bot: "Bot" = bot
         self.handle_event = self.bot.handle_event
 
+    @property
+    def config(self) -> Optional[T_Config]:
+        """适配器配置。"""
+        config_class: ConfigModel = getattr(self, "Config", None)
+        if is_config_class(config_class):
+            return getattr(self.bot.config.adapter, config_class.__config_name__, None)
+        return None
+
     async def safe_run(self):
         """附带有异常处理地安全运行适配器。"""
         try:
@@ -46,7 +56,7 @@ class Adapter(ABC):
             error_or_exception(
                 f"Run adapter {self.__class__.__name__} failed:",
                 e,
-                self.bot.config.verbose_exception_log,
+                self.bot.config.bot.log.verbose_exception,
             )
 
     @abstractmethod
