@@ -760,7 +760,7 @@ class Bot:
         self._extend_adapters.extend(adapters)
         return self._load_adapters(*adapters)
 
-    def get_loaded_adapter_by_name(self, name: str) -> Adapter:
+    def get_adapter(self, name: str) -> Adapter:
         """按照名称获取已经加载的适配器。
 
         Args:
@@ -772,10 +772,27 @@ class Bot:
         Raises:
             LookupError: 找不到此名称的适配器对象。
         """
-        for _adapter, _ in self.adapters:
+        for _adapter in self.adapters:
             if _adapter.name == name:
                 return _adapter
-        raise LookupError
+        raise LookupError(f'Can not find adapter named "{name}"')
+
+    def get_plugin(self, name: str) -> Type[Plugin]:
+        """按照名称获取已经加载的插件类。
+
+        Args:
+            name: 插件名称
+
+        Returns:
+            获取到的插件类。
+
+        Raises:
+            LookupError: 找不到此名称的插件类。
+        """
+        for _plugin in self.plugins:
+            if _plugin.name == name:
+                return _plugin
+        raise LookupError(f'Can not find plugin named "{name}"')
 
     def bot_run_hook(self, func: T_BotHook) -> T_BotHook:
         """注册一个 Bot 启动时的函数。
